<template>
	<div class="relative border border-[#dcdfe6] border-solid focus:border-[#409eff] rounded-md">
		<el-input
			v-if="defaultLanguage === 'text'"
			class="text-input nowheel [!&>textarea]:min-h-[140px]"
			v-model="editValue"
			:placeholder="placeholder"
			type="textarea"
			autocomplete="off"
			resize="none"
			:readonly="disabled"
		></el-input>
		<codemirror
			v-else
			class="nowheel overflow-auto [&>.cm-editor]:min-h-[140px] cursor-text"
			v-model="editValue"
			:autofocus="true"
			:indent-with-tab="true"
			:tab-size="2"
			:extensions="editorExtensions"
			:disabled="disabled"
		/>
		<!-- <el-tooltip effect="dark" content="全屏" placement="top">
				
				</el-tooltip> -->
		<YWIcon
			class="absolute right-1 top-1 cursor-pointer"
			:class="[defaultLanguage !== 'text' ? '!text-gray-300' : '!text-gray-500']"
			name="pingmufangda"
			@click="fullEditCodeClick"
		/>
		<!-- 切换语言 -->
		<!-- <el-select size="small" class="w-[100px] absolute top-1 right-1" v-model="defaultLanguage">
			<el-option v-for="item in language" :key="item" :value="item" :label="textTypeMap[item]"></el-option>
		</el-select> -->
		<Teleport to="body">
			<TextEditDialog
				v-model="codeEditDlgIsShow"
				:language="language"
				v-model:editValue="editValue"
				v-model:defaultLanguage="defaultLanguage"
				showCopy
				:title="title"
				:disabled="disabled"
			/>
		</Teleport>
	</div>
</template>

<script setup lang="ts" name="CodeEditor">
import { computed, onMounted, ref, type PropType } from 'vue';
import { Codemirror } from 'vue-codemirror';
import TextEditDialog from '../../dialog/TextEditDialog/index.vue';
import type { TextType } from './types';
import { useEditorExtensions } from './useEditorExtensions';
const editValue = defineModel<string>('editValue', {
	type: String,
	default: '',
});
const defaultLanguage = defineModel<TextType>('defaultLanguage', {
	type: String as PropType<TextType>,
	default: 'text',
});
const codeEditDlgIsShow = ref(false);

const props = defineProps({
	language: {
		type: Array as PropType<TextType[]>,
		default: () => ['text'],
	},
	title: {
		type: String,
		default: '代码',
	},
	maxHeight: {
		type: Number,
		default: 200,
	},
	placeholder: {
		type: String,
		default: '',
	},
	disabled: {
		type: Boolean,
		default: false,
	},
});

const { editorExtensions } = useEditorExtensions({
	activeHighlight: defaultLanguage,
});

const maxHeightPx = computed(() => {
	return `${props.maxHeight}px`;
});

const fullEditCodeClick = () => {
	codeEditDlgIsShow.value = true;
};
</script>
<style scoped lang="scss">
:deep(.cm-editor) {
	max-height: v-bind('maxHeightPx');
}

.text-input {
	:deep(textarea) {
		min-height: 140px !important;
		max-height: v-bind('maxHeightPx');
	}
}
</style>
